@@ -1,3 +1,8 @@
+"""Module containing the logic for the ``twine`` sub-commands.
+
+The contents of this package are not a public API. For more details, see
+https://github.com/pypa/twine/issues/194 and https://github.com/pypa/twine/issues/665.
+"""
 # Copyright 2013 Donald Stufft
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -13,13 +18,14 @@
 # limitations under the License.
 import glob
 import os.path
+from typing import List
 
 from twine import exceptions
 
-__all__ = []
+__all__: List[str] = []
 
 
-def _group_wheel_files_first(files):
+def _group_wheel_files_first(files: List[str]) -> List[str]:
     if not any(fname for fname in files if fname.endswith(".whl")):
         # Return early if there's no wheel files
         return files
@@ -29,7 +35,7 @@ def _group_wheel_files_first(files):
     return files
 
 
-def _find_dists(dists):
+def _find_dists(dists: List[str]) -> List[str]:
     uploads = []
     for filename in dists:
         if os.path.exists(filename):
